==> gps_api-0.1.2.tar.gz: gps_api-0.1.2/gps_api/gps_api.py <==
"""Main module."""
import serial
import haversine
from . import position

class GPS:
    def __init__(self, port):
        self.port = port
        self.ser = serial.Serial(port, baudrate=9600, timeout=0.5)
        self.nmea_msg = ""
        self.position = position.Position()

    def setup(self):
        pass

    def restart(self):
        pass

    def clean_string(self):
        self.nmea_msg = ""

    def get_latitude(self):
        self.clean_string()
        while "GPGGA" not in self.nmea_msg:
            self.nmea_msg = ser.readline().decode("utf-8", "ignore")
        self.position.update(self.nmea_msg)
        return self.position.get_latitude()

    def get_longitude(self):
        self.clean_string()
        while "GPGGA" not in self.nmea_msg:
            self.nmea_msg = ser.readline().decode("utf-8", "ignore")
        self.position.update(self.nmea_msg)
        return self.position.get_longitude()

    def get_altitude(self):
        self.clean_string()
        while "GPGGA" not in self.nmea_msg:
            self.nmea_msg = ser.readline().decode("utf-8", "ignore")
        self.position.update(self.nmea_msg)
        return self.position.get_altitude()

    def get_current_location(self):
        self.clean_string()
        while "GPGGA" not in self.nmea_msg:
            self.nmea_msg = ser.readline().decode("utf-8", "ignore")
        self.position.update(self.nmea_msg)
        return self.position.get_current_location()

    def get_current_time(self):
        self.clean_string()
        while "GPGGA" not in self.nmea_msg:
            self.nmea_msg = ser.readline().decode("utf-8", "ignore")
        self.position.update(self.nmea_msg)
        return self.position.get_current_time()

    def set_distination(self, latitude, longitude):
        self.distination = (latitude, longitude)

    def get_distance(self, latitude, longitude):
        self.set_distination(latitude, longitude)
        self.distance = haversine(self.get_current_location(), self.distination)
        return self.distance

    def get_speed(self):
        pass

    def get_time_of_arrival(self):
        pass

    def get_time_of_arrival(self, latitude, longitude):
        pass

    def store_distance(self):
        pass

    def get_mileage(self, date1, date2):
        pass

==> gps_api-0.1.3.tar.gz: gps_api-0.1.3/gps_api/gps_api.py <==
"""Main module."""
import serial
import haversine
from . import position

class GPS:
    def __init__(self, port):
        self.port = port
        self.ser = serial.Serial(port, baudrate=9600, timeout=0.5)
        self.nmea_msg = ""
        self.position = position.Position()

    def setup(self):
        pass

    def restart(self):
        pass

    def clean_string(self):
        self.nmea_msg = ""

    def get_latitude(self):
        self.clean_string()
        while "GPGGA" not in self.nmea_msg:
            self.nmea_msg = self.ser.readline().decode("utf-8", "ignore")
        self.position.update(self.nmea_msg)
        return self.position.get_latitude()

    def get_longitude(self):
        self.clean_string()
        while "GPGGA" not in self.nmea_msg:
            self.nmea_msg = self.ser.readline().decode("utf-8", "ignore")
        self.position.update(self.nmea_msg)
        return self.position.get_longitude()

    def get_altitude(self):
        self.clean_string()
        while "GPGGA" not in self.nmea_msg:
            self.nmea_msg = self.ser.readline().decode("utf-8", "ignore")
        self.position.update(self.nmea_msg)
        return self.position.get_altitude()

    def get_current_location(self):
        self.clean_string()
        while "GPGGA" not in self.nmea_msg:
            self.nmea_msg = self.ser.readline().decode("utf-8", "ignore")
        self.position.update(self.nmea_msg)
        return self.position.get_current_location()

    def get_current_time(self):
        self.clean_string()
        while "GPGGA" not in self.nmea_msg:
            self.nmea_msg = self.ser.readline().decode("utf-8", "ignore")
        self.position.update(self.nmea_msg)
        return self.position.get_current_time()

    def set_distination(self, latitude, longitude):
        self.distination = (latitude, longitude)

    def get_distance(self, latitude, longitude):
        self.set_distination(latitude, longitude)
        self.distance = haversine(self.get_current_location(), self.distination)
        return self.distance

    def get_speed(self):
        pass

    def get_time_of_arrival(self):
        pass

    def get_time_of_arrival(self, latitude, longitude):
        pass

    def store_distance(self):
        pass

    def get_mileage(self, date1, date2):
        pass
